<?php
// wbb imports
require_once(WBB_DIR.'lib/data/thread/ViewableThread.class.php');
require_once(WBB_DIR.'lib/data/board/Board.class.php');
require_once(WBB_DIR.'lib/data/page/recentActivityBox/RecentActivityBox.class.php');

/**
 * Implementation of RecentActivityBox to show the lastest threads.
 * 
 * @author 	Marcel Werk
 * @copyright	2001-2011 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb.recentActivityBox
 * @subpackage	system.event.listener
 * @category 	Burning Board
 */
class BoardRecentActivityBox implements RecentActivityBox {
	/**
	 * Cached threads
	 * @var array<ViewableThread>
	 */
	protected $cachedThreads = null;
	
	/**
	 * number of new threads
	 * @var integer
	 */
	protected $newItems = 0;
	
	/**
	 * Loads the cache.
	 */
	protected function initCache() {
		$this->cachedThreads = array();
		
		// register cache
		WCF::getCache()->addResource('boardRecentActivityBox', WBB_DIR.'cache/cache.boardRecentActivityBox.php', WBB_DIR.'lib/system/cache/CacheBuilderBoardRecentActivityBox.class.php', 0, 180);
		
		// get cache
		$cachedThreadIDArray = WCF::getCache()->get('boardRecentActivityBox');
		if (count($cachedThreadIDArray)) {
			// get board ids
			$boardIDArray = Board::getAccessibleBoardIDArray(array('canViewBoard', 'canEnterBoard', 'canReadThread'));
			foreach ($boardIDArray as $key => $boardID) {
				if (WCF::getUser()->isIgnoredBoard($boardID)) {
					unset($boardIDArray[$key]);
				}
				else if (!Board::getBoard($boardID)->searchable) {
					unset($boardIDArray[$key]);
				}
			}
			if (!count($boardIDArray)) return;
			
			// language filter
			$sqlConditionLanguage = '';
			if (count(WCF::getSession()->getVisibleLanguageIDArray()) && (BOARD_THREADS_ENABLE_LANGUAGE_FILTER_FOR_GUESTS == 1 || WCF::getUser()->userID != 0)) {
				$sqlConditionLanguage = " AND thread.languageID IN (".implode(',', WCF::getSession()->getVisibleLanguageIDArray()).")";
			}
			
			// filter cache threads
			$threadIDArray = array();
			$sql = "SELECT		thread.threadID
				FROM		wbb".WBB_N."_thread thread
				WHERE		thread.threadID IN (".implode(',', $cachedThreadIDArray).")
						AND thread.boardID IN (".implode(',', $boardIDArray).")
						AND thread.isDeleted = 0
						AND thread.isDisabled = 0
						AND thread.movedThreadID = 0
						".$sqlConditionLanguage."
				ORDER BY	thread.lastPostTime DESC";
			$result = WCF::getDB()->sendQuery($sql, RECENT_ACTIVITY_BOX_ITEMS);
			while ($row = WCF::getDB()->fetchArray($result)) {
				$threadIDArray[] = $row['threadID'];
			}
			
			// cached threads didnt contain the lastest X threads for the active user
			// fallback to non-cached function
			if (count($threadIDArray) < RECENT_ACTIVITY_BOX_ITEMS && count($cachedThreadIDArray) >= RECENT_ACTIVITY_BOX_ITEMS) {
				$threadIDArray = array();
				$sql = "SELECT		thread.threadID
					FROM		wbb".WBB_N."_thread thread
					WHERE		thread.boardID IN (".implode(',', $boardIDArray).")
							AND thread.isDeleted = 0
							AND thread.isDisabled = 0
							AND thread.movedThreadID = 0
							".$sqlConditionLanguage."
					ORDER BY	thread.lastPostTime DESC";
				$result = WCF::getDB()->sendQuery($sql, RECENT_ACTIVITY_BOX_ITEMS);
				while ($row = WCF::getDB()->fetchArray($result)) {
					$threadIDArray[] = $row['threadID'];
				}
			}
			
			// get thread data
			if (count($threadIDArray)) {
				// get sql
				$sqlSelects = $sqlJoins = '';
				if (WCF::getUser()->userID != 0) {
					// own posts
					if (BOARD_THREADS_ENABLE_OWN_POSTS) {
						$sqlSelects = "DISTINCT post.userID AS ownPosts,";
						$sqlJoins = "	LEFT JOIN	wbb".WBB_N."_post post
								ON 		(post.threadID = thread.threadID
										AND post.userID = ".WCF::getUser()->userID.")";
					}
					
					// last visit time
					$sqlSelects .= 'thread_visit.lastVisitTime,';
					$sqlJoins .= "	LEFT JOIN 	wbb".WBB_N."_thread_visit thread_visit 
							ON 		(thread_visit.threadID = thread.threadID
									AND thread_visit.userID = ".WCF::getUser()->userID.")";
					
					// subscriptions
					$sqlSelects .= 'IF(thread_subscription.userID IS NOT NULL, 1, 0) AS subscribed,';
					$sqlJoins .= "	LEFT JOIN 	wbb".WBB_N."_thread_subscription thread_subscription 
							ON 		(thread_subscription.userID = ".WCF::getUser()->userID."
									AND thread_subscription.threadID = thread.threadID)";
				}
				
				// get threads
				$sql = "SELECT		".$sqlSelects."
							thread.*
					FROM		wbb".WBB_N."_thread thread
							".$sqlJoins."
					WHERE		thread.threadID IN (".implode(',', $threadIDArray).")
					ORDER BY	thread.lastPostTime DESC";
				$result = WCF::getDB()->sendQuery($sql);
				while ($row = WCF::getDB()->fetchArray($result)) {
					// get thread
					$row['board'] = Board::getBoard($row['boardID']);
					$thread = new ViewableThread(null, $row);
					$this->cachedThreads[] = $thread;
					
					// get new status
					if ($thread->isNew()) $this->newItems++;
				}
			}
		}
	}
	
	/**
	 * @see RecentActivityBox::getIdentifier()
	 */
	public function getIdentifier() {
		return 'com.woltlab.wbb.threads';
	}
	
	/**
	 * @see RecentActivityBox::getTitle()
	 */
	public function getTitle() {
		return WCF::getLanguage()->get('wbb.board.threads.normal');
	}
	
	/**
	 * @see RecentActivityBox::getNewItems()
	 */
	public function getNewItems() {
		return $this->newItems;
	}
	
	/**
	 * @see RecentActivityBox::hasContent()
	 */
	public function hasContent() {
		if ($this->cachedThreads === null) $this->initCache();
		
		if (count($this->cachedThreads)) {
			return true;
		}
		return false;
	}
	
	/**
	 * @see RecentActivityBox::getContent()
	 */
	public function getContent() {
		if ($this->hasContent()) {
			WCF::getTPL()->assign('threads', $this->cachedThreads);
			return WCF::getTPL()->fetch('boardRecentActivityBox');
		}
		return '';
	}
}
?>