<?php
// wbb imports
require_once(WBB_DIR.'lib/data/page/recentActivityBox/RecentActivityBox.class.php');

/**
 * Manages the data of the recent activity box.
 * 
 * @author 	Marcel Werk
 * @copyright	2001-2011 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wbb.recentActivityBox
 * @subpackage	data.page.recentActivityBox
 * @category 	Burning Board
 */
class RecentActivityBoxManager {
	/**
	 * RecentActivityBox instance
	 * @var RecentActivityBox
	 */
	private static $instance = null;
	
	/**
	 * List of recent activity boxes.
	 * @var array<RecentActivityBox>
	 */
	private $boxes = array();
	
	/**
	 * Creates a new RecentActivityBox object.
	 */
	private function __construct() {}
	
	/**
	 * Returns an instance of RecentActivityBox.
	 * 
	 * @return RecentActivityBox
	 */
	public static function getInstance() {
		if (self::$instance === null) {
			self::$instance = new RecentActivityBoxManager();
		}
		
		return self::$instance;
	}
	
	/**
	 * Adds a new box.
	 * 
	 * @param	RecentActivityBox	$box
	 */
	public function addBox(RecentActivityBox $box) {
		$this->boxes[$box->getIdentifier()] = $box;
	}
	
	/**
	 * Removes a box.
	 * 
	 * @param	string		$identifier
	 */
	public function removeBox($identifier) {
		if (isset($this->boxes[$identifier])) unset($this->boxes[$identifier]);
	}
	
	/**
	 * Returns all boxes.
	 * 
	 * @return array<RecentActivityBox>
	 */
	public function getBoxes() {
		return $this->boxes;
	}
}
?>